# Slider

Slide overlay software based on beamer and inkscape. This project is currently used in coursebox. 
The software also offers a package for jinja2 (jinjafy) which offers a handful of convenient extensions.